@@ -239,6 +239,10 @@ my $options = [
       justify => 2, keep => 8, clear_screen => 1, pad_one_row => 4 },
     { prompt => 'abc 12345678 def' x 50, default => 10, empty =>' ', undef => '--', beep => 1,
       no_spacebar => [ 11 .. 2000 ], lf => [ 0, 4 ], keep => 16 },
+    { max_height => 20, max_width => 60, layout => 0, mark => [ 0, 10, 100 ] },
+    { max_height => 20, max_width => 60, layout => 1, mark => [ 0, 10, 100 ] },
+    { max_height => 20, max_width => 60, layout => 2, mark => [ 0, 10, 35, 100, 1979 ], no_spacebar => [ 35, 1066, 1979 ] },
+    { max_height => 20, max_width => 60, layout => 3, mark => [ 0, 10, 100 ] },
 ];
 
 
@@ -306,6 +310,26 @@ my $long = [
         expected  => "<0 10 1846>",
         options   => $options->[$c_opt++],
     },
+    {   list      => $list->{long},
+        used_keys => $keys->{long},
+        expected  => "<0 10 100 1066 1126 1315 1324 1799 1857 1859 1863 1866 1917 1979 1999>",
+        options   => $options->[$c_opt++],
+    },
+    {   list      => $list->{long},
+        used_keys => $keys->{long},
+        expected  => "<0 10 100 1066 1126 1315 1324 1799 1857 1859 1863 1866 1917 1979 1999>",
+        options   => $options->[$c_opt++],
+    },
+    {   list      => $list->{long},
+        used_keys => $keys->{long},
+        expected  => "<0 10 35 100 1126 1315 1324 1799 1857 1859 1863 1866 1917 1979 1999>",
+        options   => $options->[$c_opt++],
+    },
+    {   list      => $list->{long},
+        used_keys => $keys->{long},
+        expected  => "<0 10 100 1859 1869 1872 1907 1916 1929 1935 1979 1999>",
+        options   => $options->[$c_opt++],
+    },
 ];
 
 $c_opt = 0;
@@ -371,6 +395,26 @@ my $short = [
         expected_w81 => "<0 10 93>",
         options   => $options->[$c_opt++],
     },
+    {   list      => $list->{short},
+        used_keys => $keys->{short},
+        expected  => "<0 7 12 67 93 99>",
+        options   => $options->[$c_opt++],
+    },
+    {   list      => $list->{short},
+        used_keys => $keys->{short},
+        expected  => "<0 10 41 44 47 50 91 99>",
+        options   => $options->[$c_opt++],
+    },
+    {   list      => $list->{short},
+        used_keys => $keys->{short},
+        expected  => "<0 10 35 38 41 69 85 99>",
+        options   => $options->[$c_opt++],
+    },
+    {   list      => $list->{short},
+        used_keys => $keys->{short},
+        expected  => "<0 10 64 67 70 89 99>",
+        options   => $options->[$c_opt++],
+    },
 ];
 
 my $option_ll = [
@@ -399,19 +443,18 @@ my $pad_one_row = [
 
 sub return_test_data {
     my $type = shift;
-       if ( $type eq 'simple'        ) { return $simple; }
-    elsif ( $type eq 'hide_cursor'   ) { return $hide_cursor; }
-    elsif ( $type eq 'seq_test'      ) { return $seq_test; }
-    elsif ( $type eq 'long'          ) { return $long; }
-    elsif ( $type eq 'short'         ) { return $short; }
-    elsif ( $type eq 'option_ll'     ) { return $option_ll; }
-    elsif ( $type eq 'pad_one_row'   ) { return $pad_one_row; }
+       if ( $type eq 'simple'      ) { return $simple; }
+    elsif ( $type eq 'hide_cursor' ) { return $hide_cursor; }
+    elsif ( $type eq 'seq_test'    ) { return $seq_test; }
+    elsif ( $type eq 'long'        ) { return $long; }
+    elsif ( $type eq 'short'       ) { return $short; }
+    elsif ( $type eq 'option_ll'   ) { return $option_ll; }
+    elsif ( $type eq 'pad_one_row' ) { return $pad_one_row; }
 
 }
 
 
 
-
 1;
 
 __END__
